@@ -3,7 +3,6 @@ knitr::opts_chunk$set(comment = NA)
 
 ## ----message = FALSE----------------------------------------------------------
 library(StepReg)
-
 data(mtcars)
 formula <- mpg ~ .
 res <- stepwise(formula = formula,
@@ -17,10 +16,14 @@ res <- stepwise(formula = formula,
 res
 
 ## ----message = FALSE----------------------------------------------------------
-plot(res)
+summary(res$bidirection$AIC)
+
+## ----message = FALSE----------------------------------------------------------
+plot(res, strategy = "bidirection", process = "overview")
+plot(res, strategy = "bidirection", process = "details")
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  report(res, report_name = "path_to/demo_res", format = "html")
+# report(res, report_name = "path_to/demo_res", format = "html")
 
 ## ----echo = FALSE-------------------------------------------------------------
 library(knitr)
@@ -118,25 +121,10 @@ kable(df, format = "html", align = "l",
   column_spec(3, width = "0.5in") %>%
   column_spec(4, width = "0.4in")
 
-## ----echo = FALSE-------------------------------------------------------------
-Table_Name <- c("Summary of arguments for model selection",
-                "Summary of variables in dataset",
-                "Summary of selection process under xxx(strategy) with xxx(metric)",
-                "Summary of coefficients for the selected model with xxx(dependent variable) under xxx(strategy) and xxx(metric)")
-
-Table_Description <- c("Arguments used in the stepwise function, either default or user-supplied values.",
-                       "Variable names, types, and classes in dataset.",
-                       "Overview of the variable selection process under specified strategy and metric.",
-                       "Coefficients for the selected models under specified strategy with metric. Please note that this table will not be generated for the strategy 'subset' when using the metric 'SL'.")
-data.frame(Table_Name, Table_Description) %>% 
-  kable(format = "html", align = 'l', escape = F, caption = "Tables generated by StepReg") %>%
-  kable_styling()
-
 ## ----eval = FALSE-------------------------------------------------------------
-#  report(res, report_name = "results", format = c("xlsx", "docx"))
+# report(res, report_name = "results", format = c("xlsx", "docx"))
 
 ## ----message = FALSE----------------------------------------------------------
-library(StepReg)
 data(mtcars)
 
 formula <- mpg ~ .
@@ -149,17 +137,22 @@ res1 <- stepwise(formula = formula,
 res1
 
 ## ----plot_res1, warning = FALSE-----------------------------------------------
-plot_list <- plot(res1)
+plot_list <- list()
+plot_list[["forward"]][["details"]] <- plot(res1, process = "details")
+plot_list[["forward"]][["overview"]] <- plot(res1, process = "overview")
 cowplot::plot_grid(plotlist = plot_list$forward, ncol = 1)
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  formula <- mpg ~ . + 0
+# formula <- mpg ~ . + 0
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  formula <- mpg ~ cyl + disp + hp + wt + vs + am + 0
+# formula <- mpg ~ . - 1
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  formula <- mpg ~ . - 1 - disp - wt
+# formula <- mpg ~ cyl + disp + hp + wt + vs + am + 0
+
+## ----eval = FALSE-------------------------------------------------------------
+# formula <- mpg ~ . - 1 - disp - wt
 
 ## ----message = FALSE, warning = FALSE-----------------------------------------
 formula <- mpg ~ .
@@ -173,7 +166,18 @@ res2 <- stepwise(formula = formula,
 res2
 
 ## ----message = FALSE, warning = FALSE, fig.width=9, fig.height=12-------------
-plot_list <- plot(res2)
+plot_list <- setNames(
+  lapply(c("forward", "backward"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res2,strategy=i,process=j)
+    }),
+    c("details","overview")
+    )
+  }),
+  c("forward", "backward")
+)
+
 cowplot::plot_grid(plotlist = plot_list$forward, ncol = 1, rel_heights = c(2, 1))
 cowplot::plot_grid(plotlist = plot_list$backward, ncol = 1, rel_heights = c(2, 1))
 
@@ -185,7 +189,20 @@ res3 <- stepwise(formula = formula,
                  strategy = "bidirection",
                  metric = c("AIC", "HQ"))
 res3
-plot(res3)
+
+plot_list <- setNames(
+  lapply(c("bidirection"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res3,strategy=i,process=j)
+    }),
+    c("details","overview")
+    )
+  }),
+  c("bidirection")
+)
+
+cowplot::plot_grid(plotlist = plot_list$bidirection, ncol = 1, rel_heights = c(2, 1))
 
 ## ----message = FALSE----------------------------------------------------------
 data(remission)
@@ -198,7 +215,19 @@ res4 <- stepwise(formula = formula,
                  strategy = "forward",
                  metric = "AIC")
 res4
-plot(res4)
+
+plot_list <- setNames(
+  lapply(c("forward"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res4,strategy=i,process=j)
+    }),
+    c("details","overview")
+    )
+  }),
+  c("forward")
+)
+cowplot::plot_grid(plotlist = plot_list$forward, ncol = 1, rel_heights = c(2, 1))
 
 ## ----message = FALSE----------------------------------------------------------
 data(remission)
@@ -211,7 +240,19 @@ res5 <- stepwise(formula = formula,
                   metric = "SBC",
                   best_n = 3)
 res5
-plot(res5)
+
+plot_list <- setNames(
+  lapply(c("subset"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res5,strategy=i,process=j)
+    }),
+    c("details","overview")
+    )
+  }),
+  c("subset")
+)
+cowplot::plot_grid(plotlist = plot_list$subset, ncol = 1, rel_heights = c(2, 1))
 
 ## ----message = FALSE----------------------------------------------------------
 library(dplyr)
@@ -228,7 +269,19 @@ res6 <- stepwise(formula = formula,
                  strategy = "forward",
                  metric = "AICc")
 res6
-plot(res6)
+
+plot_list <- setNames(
+  lapply(c("forward"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res6,strategy=i,process=j)
+    }),
+    c("details","overview")
+    )
+  }),
+  c("forward")
+)
+cowplot::plot_grid(plotlist = plot_list$forward, ncol = 1, rel_heights = c(2, 1))
 
 ## ----message = FALSE----------------------------------------------------------
 data(creditCard)
@@ -240,12 +293,25 @@ res7 <- stepwise(formula = formula,
                  strategy = "forward",
                  metric = "SL",
                  sle = 0.05)
-res7
-plot(res7)
+summary(res7$forward$SL)
+
+## ----message = FALSE----------------------------------------------------------
+plot_list <- setNames(
+  lapply(c("forward"),function(i){
+    setNames(
+      lapply(c("details","overview"),function(j){
+        plot(res7,strategy=i,process=j)
+      }),
+      c("details","overview")
+    )
+  }),
+  c("forward")
+)
+cowplot::plot_grid(plotlist = plot_list$forward, ncol = 1, rel_heights = c(2, 1))
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  library(StepReg)
-#  StepRegShinyApp()
+# library(StepReg)
+# StepRegShinyApp()
 
 ## ----sessionInfo, echo = FALSE------------------------------------------------
 sessionInfo()
